@@ -12,6 +12,7 @@ import java.io.Reader;
 import java.sql.Array;
 import java.sql.Blob;
 import java.sql.CallableStatement;
+import java.sql.ClientInfoStatus;
 import java.sql.Clob;
 import java.sql.Connection;
 import java.sql.DatabaseMetaData;
@@ -25,14 +26,22 @@ import java.sql.SQLXML;
 import java.sql.Savepoint;
 import java.sql.Statement;
 import java.sql.Struct;
+
+/*## Java 1.7 ##
+import java.util.concurrent.Executor;
+//*/
+
 import java.util.ArrayList;
+import java.util.Collections;
+import java.util.HashMap;
 import java.util.Map;
 import java.util.Properties;
-
+import java.util.regex.Pattern;
 import org.h2.api.ErrorCode;
 import org.h2.command.CommandInterface;
 import org.h2.engine.ConnectionInfo;
 import org.h2.engine.Constants;
+import org.h2.engine.Mode;
 import org.h2.engine.SessionInterface;
 import org.h2.engine.SessionRemote;
 import org.h2.engine.SysProperties;
@@ -48,10 +57,6 @@ import org.h2.value.ValueInt;
 import org.h2.value.ValueNull;
 import org.h2.value.ValueString;
 
-/*## Java 1.7 ##
-import java.util.concurrent.Executor;
-//*/
-
 /**
  * <p>
  * Represents a connection (session) to a database.
@@ -64,6 +69,9 @@ import java.util.concurrent.Executor;
  */
 public class JdbcConnection extends TraceObject implements Connection {
 
+    private static final String NUM_SERVERS = "numServers";
+    private static final String PREFIX_SERVER = "server";
+
     private static boolean keepOpenStackTrace;
 
     private final String url;
@@ -84,6 +92,9 @@ public class JdbcConnection extends TraceObject implements Connection {
     private final CloseWatcher watcher;
     private int queryTimeoutCache = -1;
 
+    private Map<String, String> clientInfo;
+    private String mode;
+
     /**
      * INTERNAL
      */
@@ -140,6 +151,9 @@ public class JdbcConnection extends TraceObject implements Connection {
         this.getReadOnly = clone.getReadOnly;
         this.rollback = clone.rollback;
         this.watcher = null;
+        if (clone.clientInfo != null) {
+            this.clientInfo = new HashMap<String, String>(clone.clientInfo);
+        }
     }
 
     /**
@@ -1661,11 +1675,26 @@ public class JdbcConnection extends TraceObject implements Connection {
     }
 
     /**
-     * Set a client property.
-     * This method always throws a SQLClientInfoException.
+     * Set a client property. This method always throws a SQLClientInfoException
+     * in standard mode. In compatibility mode the following properties are
+     * supported:
+     * <ul>
+     * <li>DB2: The properties: ApplicationName, ClientAccountingInformation,
+     * ClientUser and ClientCorrelationToken are supported.
+     * </li>
+     * <li>MySQL: All property names are supported.
+     * </li>
+     * <li>Oracle: All properties in the form &lt;namespace&gt;.&lt;key name&gt;
+     * are supported.
+     * </li>
+     * <li>PostgreSQL: The ApplicationName property is supported.
+     * </li>
+     * </ul>
      *
-     * @param name the name of the property (ignored)
-     * @param value the value (ignored)
+     * For unsupported properties a SQLClientInfoException is thrown.
+     *
+     * @param name the name of the property
+     * @param value the value
      */
     @Override
     public void setClientInfo(String name, String value)
@@ -1677,13 +1706,34 @@ public class JdbcConnection extends TraceObject implements Connection {
                         +quote(value)+");");
             }
             checkClosed();
-            // we don't have any client properties, so just throw
-            throw new SQLClientInfoException();
+
+            if (isInternalProperty(name)) {
+                throw new SQLClientInfoException("Property name '" + name +
+                        " is used internally by H2.",
+                        Collections.<String, ClientInfoStatus> emptyMap());
+            }
+
+            Pattern clientInfoNameRegEx =
+                    Mode.getInstance(getMode()).supportedClientInfoPropertiesRegEx;
+
+            if (clientInfoNameRegEx != null && clientInfoNameRegEx.matcher(name).matches()) {
+                if (clientInfo == null) {
+                    clientInfo = new HashMap<String, String>();
+                }
+                clientInfo.put(name, value);
+            } else {
+                throw new SQLClientInfoException("Client info name '" + name + "' not supported.",
+                        Collections.<String, ClientInfoStatus> emptyMap());
+            }
         } catch (Exception e) {
             throw convertToClientInfoException(logAndConvert(e));
         }
     }
 
+    private static boolean isInternalProperty(String name) {
+        return NUM_SERVERS.equals(name) || name.startsWith(PREFIX_SERVER);
+    }
+
     private static SQLClientInfoException convertToClientInfoException(
             SQLException x) {
         if (x instanceof SQLClientInfoException) {
@@ -1694,8 +1744,11 @@ public class JdbcConnection extends TraceObject implements Connection {
     }
 
     /**
-     * Set the client properties.
-     * This method always throws a SQLClientInfoException.
+     * Set the client properties. This replaces all existing properties.
+     *
+     * This method always throws a SQLClientInfoException in standard mode. In
+     * compatibility mode some properties may be supported (see
+     * setProperty(String, String) for details).
      *
      * @param properties the properties (ignored)
      */
@@ -1706,8 +1759,14 @@ public class JdbcConnection extends TraceObject implements Connection {
                 debugCode("setClientInfo(properties);");
             }
             checkClosed();
-            // we don't have any client properties, so just throw
-            throw new SQLClientInfoException();
+            if (clientInfo == null) {
+                clientInfo = new HashMap<String, String>();
+            } else {
+                clientInfo.clear();
+            }
+            for (Map.Entry<Object, Object> entry : properties.entrySet()) {
+                setClientInfo((String) entry.getKey(), (String) entry.getValue());
+            }
         } catch (Exception e) {
             throw convertToClientInfoException(logAndConvert(e));
         }
@@ -1728,10 +1787,18 @@ public class JdbcConnection extends TraceObject implements Connection {
             ArrayList<String> serverList = session.getClusterServers();
             Properties p = new Properties();
 
-            p.setProperty("numServers", String.valueOf(serverList.size()));
-            for (int i = 0; i < serverList.size(); i++) {
-                p.setProperty("server" + String.valueOf(i), serverList.get(i));
+            if (clientInfo != null) {
+                for (Map.Entry<String, String> entry : clientInfo.entrySet()) {
+                    p.setProperty(entry.getKey(), entry.getValue());
+                }
             }
+
+            p.setProperty(NUM_SERVERS, String.valueOf(serverList.size()));
+            for (int i = 0; i < serverList.size(); i++) {
+                p.setProperty(PREFIX_SERVER + String.valueOf(i), serverList.get(i));
+            }
+
+
             return p;
         } catch (Exception e) {
             throw logAndConvert(e);
@@ -1741,8 +1808,9 @@ public class JdbcConnection extends TraceObject implements Connection {
     /**
      * Get a client property.
      *
-     * @param name the client info name (ignored)
-     * @return the property value
+     * @param name the client info name
+     * @return the property value or null if the property is not found or not
+     *         supported.
      */
     @Override
     public String getClientInfo(String name) throws SQLException {
@@ -1751,12 +1819,7 @@ public class JdbcConnection extends TraceObject implements Connection {
                 debugCodeCall("getClientInfo", name);
             }
             checkClosed();
-            Properties p = getClientInfo();
-            String s = p.getProperty(name);
-            if (s == null) {
-                throw new SQLClientInfoException();
-            }
-            return s;
+            return getClientInfo().getProperty(name);
         } catch (Exception e) {
             throw logAndConvert(e);
         }
@@ -1947,4 +2010,17 @@ public class JdbcConnection extends TraceObject implements Connection {
         trace.setLevel(level);
     }
 
+    String getMode() throws SQLException {
+        if (mode == null) {
+            PreparedStatement prep = prepareStatement(
+                    "SELECT VALUE FROM INFORMATION_SCHEMA.SETTINGS WHERE NAME=?");
+            prep.setString(1, "MODE");
+            ResultSet rs = prep.executeQuery();
+            rs.next();
+            mode = rs.getString(1);
+            prep.close();
+        }
+        return mode;
+    }
+
 }
