@@ -49,6 +49,7 @@ import org.h2.value.ValueStringFixed;
 import org.h2.value.ValueStringIgnoreCase;
 import org.h2.value.ValueTime;
 import org.h2.value.ValueTimestamp;
+import org.h2.value.ValueTimestampTimeZone;
 import org.h2.value.ValueTimestampUtc;
 import org.h2.value.ValueUuid;
 
@@ -544,7 +545,15 @@ public class Data {
             writeVarLong(ts.getUtcDateTimeNanos());
             break;
         }
+        case Value.TIMESTAMP_TZ: {
+            ValueTimestampTimeZone ts = (ValueTimestampTimeZone) v;
+            writeByte((byte) type);
+            writeVarLong(ts.getDateValue());
+            writeVarLong(ts.getTimeNanos());
+            writeVarInt(ts.getTimeZoneOffsetMins());
+        }
         case Value.GEOMETRY:
+            // fall though
         case Value.JAVA_OBJECT: {
             writeByte((byte) type);
             byte[] b = v.getBytesNoCopy();
@@ -781,6 +790,12 @@ public class Data {
         case Value.TIMESTAMP_UTC: {
             return ValueTimestampUtc.fromNanos(readVarLong());
         }
+        case Value.TIMESTAMP_TZ: {
+            long dateValue = readVarLong();
+            long nanos = readVarLong();
+            short tz = (short) readVarInt();
+            return ValueTimestampTimeZone.fromDateValueAndNanos(dateValue, nanos, tz);
+        }
         case Value.BYTES: {
             int len = readVarInt();
             byte[] b = DataUtils.newBytes(len);
@@ -1033,6 +1048,14 @@ public class Data {
             ValueTimestampUtc ts = (ValueTimestampUtc) v;
             return 1 + getVarLongLen(ts.getUtcDateTimeNanos());
         }
+        case Value.TIMESTAMP_TZ: {
+            ValueTimestampTimeZone ts = (ValueTimestampTimeZone) v;
+            long dateValue = ts.getDateValue();
+            long nanos = ts.getTimeNanos();
+            short tz = ts.getTimeZoneOffsetMins();
+            return 1 + getVarLongLen(dateValue) + getVarLongLen(nanos) +
+                    getVarIntLen(tz);
+        }
         case Value.GEOMETRY:
         case Value.JAVA_OBJECT: {
             byte[] b = v.getBytesNoCopy();
