@@ -31,6 +31,7 @@ import org.h2.value.ValueNull;
 import org.h2.value.ValueString;
 import org.h2.value.ValueTime;
 import org.h2.value.ValueTimestamp;
+import org.h2.value.ValueTimestampTimeZone;
 import org.h2.value.ValueTimestampUtc;
 import org.h2.value.ValueUuid;
 
@@ -94,7 +95,7 @@ public class Column {
             int displaySize) {
         this.name = name;
         this.type = type;
-        if (precision == -1 && scale == -1 && displaySize == -1) {
+        if (precision == -1 && scale == -1 && displaySize == -1 && type != Value.UNKNOWN) {
             DataType dt = DataType.getDataType(type);
             precision = dt.defaultPrecision;
             scale = dt.defaultScale;
@@ -296,6 +297,9 @@ public class Column {
                         value = ValueTimestamp.fromMillis(session.getTransactionStart());
                     } else if (dt.type == Value.TIMESTAMP_UTC) {
                         value = ValueTimestampUtc.fromMillis(session.getTransactionStart());
+                    } else if (dt.type == Value.TIMESTAMP_TZ) {
+                        value = ValueTimestampTimeZone.fromMillis(
+                                session.getTransactionStart(), (short) 0);
                     } else if (dt.type == Value.TIME) {
                         value = ValueTime.fromNanos(0);
                     } else if (dt.type == Value.DATE) {
