@@ -9,6 +9,7 @@ import java.io.BufferedReader;
 import java.io.InputStream;
 import java.io.Reader;
 import java.math.BigDecimal;
+import java.math.BigInteger;
 import java.sql.Array;
 import java.sql.Blob;
 import java.sql.Clob;
@@ -23,6 +24,7 @@ import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.UUID;
 import org.h2.api.ErrorCode;
+import org.h2.api.TimestampWithTimeZone;
 import org.h2.engine.Constants;
 import org.h2.engine.SessionInterface;
 import org.h2.engine.SysProperties;
@@ -321,6 +323,13 @@ public class DataType {
                 // 24 for ValueTimestampUtc, 32 for java.sql.Timestamp
                 56
         );
+        add(Value.TIMESTAMP_TZ, Types.OTHER, "TimestampTimeZone",
+                createDate(ValueTimestampTimeZone.PRECISION, "TIMESTAMP_TZ",
+                        ValueTimestampTimeZone.DEFAULT_SCALE, ValueTimestampTimeZone.DISPLAY_SIZE),
+                new String[]{"TIMESTAMP WITH TIMEZONE"},
+                // 26 for ValueTimestampUtc, 32 for java.sql.Timestamp
+                58
+        );
         add(Value.BYTES, Types.VARBINARY, "Bytes",
                 createString(false),
                 new String[]{"VARBINARY"},
@@ -551,6 +560,12 @@ public class DataType {
                     ValueTimestampUtc.fromMillisNanos(value.getTime(), value.getNanos());
                 break;
             }
+            case Value.TIMESTAMP_TZ: {
+                TimestampWithTimeZone value = (TimestampWithTimeZone) rs.getTimestamp(columnIndex);
+                v = value == null ? (Value) ValueNull.INSTANCE :
+                    ValueTimestampTimeZone.get(value);
+                break;
+            }
             case Value.DECIMAL: {
                 BigDecimal value = rs.getBigDecimal(columnIndex);
                 v = value == null ? (Value) ValueNull.INSTANCE :
@@ -726,6 +741,9 @@ public class DataType {
         case Value.TIMESTAMP_UTC:
             // "java.sql.Timestamp";
             return Timestamp.class.getName();
+        case Value.TIMESTAMP_TZ:
+            // "org.h2.api.TimestampWithTimeZone";
+            return TimestampWithTimeZone.class.getName();
         case Value.BYTES:
         case Value.UUID:
             // "[B", not "byte[]";
@@ -998,6 +1016,8 @@ public class DataType {
             return ValueLong.get(((Long) x).longValue());
         } else if (x instanceof Integer) {
             return ValueInt.get(((Integer) x).intValue());
+        } else if (x instanceof BigInteger) {
+            return ValueDecimal.get(new BigDecimal((BigInteger) x));
         } else if (x instanceof BigDecimal) {
             return ValueDecimal.get((BigDecimal) x);
         } else if (x instanceof Boolean) {
