@@ -35,6 +35,7 @@ public class TestAlter extends TestBase {
         deleteDb(getTestName());
         conn = getConnection(getTestName());
         stat = conn.createStatement();
+        testAlterTableRenameConstraint();
         testAlterTableAlterColumnAsSelfColumn();
         testAlterTableDropColumnWithReferences();
         testAlterTableDropMultipleColumns();
@@ -140,6 +141,13 @@ public class TestAlter extends TestBase {
         stat.execute("drop table test");
     }
 
+    private void testAlterTableRenameConstraint() throws SQLException {
+        stat.execute("create table test(id int, name varchar(255))");
+        stat.execute("alter table test add constraint x check (id > name)");
+        stat.execute("alter table test rename constraint x to x2");
+        stat.execute("drop table test");
+    }
+
     private void testAlterTableDropIdentityColumn() throws SQLException {
         stat.execute("create table test(id int auto_increment, name varchar)");
         stat.execute("alter table test drop column id");
