@@ -39,7 +39,7 @@ import org.h2.value.ValueGeometry;
  */
 public class TestSpatial extends TestBase {
 
-    private String url = "spatial";
+    private static final String URL = "spatial";
 
     /**
      * Run just this test.
@@ -60,13 +60,13 @@ public class TestSpatial extends TestBase {
         }
         if (DataType.GEOMETRY_CLASS != null) {
             deleteDb("spatial");
-            url = "spatial";
             testSpatial();
             deleteDb("spatial");
         }
     }
 
     private void testSpatial() throws SQLException {
+        testBug1();
         testSpatialValues();
         testOverlap();
         testNotOverlap();
@@ -95,6 +95,21 @@ public class TestSpatial extends TestBase {
         testNullableGeometryUpdate();
     }
 
+    private void testBug1() throws SQLException {
+        deleteDb("spatial");
+        Connection conn = getConnection(URL);
+        Statement stat = conn.createStatement();
+
+        stat.execute("CREATE TABLE VECTORS (ID INTEGER NOT NULL, GEOM GEOMETRY, S INTEGER)");
+        stat.execute("INSERT INTO VECTORS(ID, GEOM, S) " +
+                "VALUES(0, 'POLYGON ((30 10, 40 40, 20 40, 10 20, 30 10))', 1)");
+
+        stat.executeQuery("select * from (select * from VECTORS) WHERE S=1 " +
+                "AND GEOM && 'POLYGON ((30 10, 40 40, 20 40, 10 20, 30 10))'");
+        conn.close();
+        deleteDb("spatial");
+    }
+
     private void testHashCode() {
         ValueGeometry geomA = ValueGeometry
                 .get("POLYGON ((67 13 6, 67 18 5, 59 18 4, 59 13 6,  67 13 6))");
@@ -108,7 +123,7 @@ public class TestSpatial extends TestBase {
 
     private void testSpatialValues() throws SQLException {
         deleteDb("spatial");
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         Statement stat = conn.createStatement();
 
         stat.execute("create memory table test" +
@@ -173,7 +188,7 @@ public class TestSpatial extends TestBase {
 
     private void testOverlap() throws SQLException {
         deleteDb("spatial");
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         try {
             Statement stat = conn.createStatement();
             stat.execute("create memory table test" +
@@ -198,7 +213,7 @@ public class TestSpatial extends TestBase {
     }
     private void testPersistentSpatialIndex() throws SQLException {
         deleteDb("spatial");
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         try {
             Statement stat = conn.createStatement();
             stat.execute("create table test" +
@@ -239,7 +254,7 @@ public class TestSpatial extends TestBase {
             return;
         }
 
-        conn = getConnection(url);
+        conn = getConnection(URL);
         try {
             Statement stat = conn.createStatement();
             ResultSet rs = stat.executeQuery(
@@ -256,7 +271,7 @@ public class TestSpatial extends TestBase {
     }
     private void testNotOverlap() throws SQLException {
         deleteDb("spatial");
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         try {
             Statement stat = conn.createStatement();
             stat.execute("create memory table test" +
@@ -333,7 +348,7 @@ public class TestSpatial extends TestBase {
 
     private void testSpatialIndexQueryMultipleTable() throws SQLException {
         deleteDb("spatial");
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         try {
             Statement stat = conn.createStatement();
             createTestTable(stat);
@@ -374,7 +389,7 @@ public class TestSpatial extends TestBase {
     private void testIndexTransaction() throws SQLException {
         // Check session management in index
         deleteDb("spatial");
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         conn.setAutoCommit(false);
         try {
             Statement stat = conn.createStatement();
@@ -423,7 +438,7 @@ public class TestSpatial extends TestBase {
      */
     private void testMemorySpatialIndex() throws SQLException {
         deleteDb("spatial");
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         Statement stat = conn.createStatement();
 
         stat.execute("create memory table test(id int primary key, polygon geometry)");
@@ -486,7 +501,7 @@ public class TestSpatial extends TestBase {
      */
     private void testJavaAlias() throws SQLException {
         deleteDb("spatial");
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         try {
             Statement stat = conn.createStatement();
             stat.execute("CREATE ALIAS T_GEOM_FROM_TEXT FOR \"" +
@@ -512,7 +527,7 @@ public class TestSpatial extends TestBase {
      */
     private void testJavaAliasTableFunction() throws SQLException {
         deleteDb("spatial");
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         try {
             Statement stat = conn.createStatement();
             stat.execute("CREATE ALIAS T_RANDOM_GEOM_TABLE FOR \"" +
@@ -621,7 +636,7 @@ public class TestSpatial extends TestBase {
      */
     private void testValueConversion() throws SQLException {
         deleteDb("spatial");
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         Statement stat = conn.createStatement();
         stat.execute("CREATE ALIAS OBJ_STRING FOR \"" +
                 TestSpatial.class.getName() +
@@ -679,7 +694,7 @@ public class TestSpatial extends TestBase {
      */
     private void testTableFunctionGeometry() throws SQLException {
         deleteDb("spatial");
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         try {
             Statement stat = conn.createStatement();
             stat.execute("CREATE ALIAS POINT_TABLE FOR \"" +
@@ -776,7 +791,7 @@ public class TestSpatial extends TestBase {
 
     private void testTableViewSpatialPredicate() throws SQLException {
         deleteDb("spatial");
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         try {
             Statement stat = conn.createStatement();
             stat.execute("drop table if exists test");
@@ -814,7 +829,7 @@ public class TestSpatial extends TestBase {
      */
     private void testValueGeometryScript() throws SQLException {
         ValueGeometry valueGeometry = ValueGeometry.get("POINT(1 1 5)");
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         try {
             ResultSet rs = conn.createStatement().executeQuery(
                     "SELECT " + valueGeometry.getSQL());
@@ -832,7 +847,7 @@ public class TestSpatial extends TestBase {
      * be updated.
      */
     private void testInPlaceUpdate() throws SQLException {
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         try {
             ResultSet rs = conn.createStatement().executeQuery(
                     "SELECT 'POINT(1 1)'::geometry");
@@ -855,7 +870,7 @@ public class TestSpatial extends TestBase {
 
     private void testScanIndexOnNonSpatialQuery() throws SQLException {
         deleteDb("spatial");
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         try {
             Statement stat = conn.createStatement();
             stat.execute("drop table if exists test");
@@ -874,7 +889,7 @@ public class TestSpatial extends TestBase {
 
     private void testStoreCorruption() throws SQLException {
         deleteDb("spatial");
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         try {
             Statement stat = conn.createStatement();
             stat.execute("drop table if exists pt_cloud;\n" +
@@ -903,7 +918,7 @@ public class TestSpatial extends TestBase {
 
     private void testExplainSpatialIndexWithPk() throws SQLException {
         deleteDb("spatial");
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         try {
             Statement stat = conn.createStatement();
             stat.execute("drop table if exists pt_cloud;");
@@ -930,7 +945,7 @@ public class TestSpatial extends TestBase {
 
     private void testNullableGeometry() throws SQLException {
         deleteDb("spatial");
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         Statement stat = conn.createStatement();
 
         stat.execute("create memory table test"
@@ -984,7 +999,7 @@ public class TestSpatial extends TestBase {
 
         conn.close();
         if (!config.memory) {
-            conn = getConnection(url);
+            conn = getConnection(URL);
             stat = conn.createStatement();
             rs = stat.executeQuery("select * from test");
             assertTrue(rs.next());
@@ -997,7 +1012,7 @@ public class TestSpatial extends TestBase {
 
     private void testNullableGeometryDelete() throws SQLException {
         deleteDb("spatial");
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         Statement stat = conn.createStatement();
         stat.execute("create memory table test"
                 + "(id int primary key, the_geom geometry)");
@@ -1024,7 +1039,7 @@ public class TestSpatial extends TestBase {
 
     private void testNullableGeometryInsert() throws SQLException {
         deleteDb("spatial");
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         Statement stat = conn.createStatement();
         stat.execute("create memory table test"
                 + "(id identity, the_geom geometry)");
@@ -1042,7 +1057,7 @@ public class TestSpatial extends TestBase {
 
     private void testNullableGeometryUpdate() throws SQLException {
         deleteDb("spatial");
-        Connection conn = getConnection(url);
+        Connection conn = getConnection(URL);
         Statement stat = conn.createStatement();
         stat.execute("create memory table test"
                 + "(id int primary key, the_geom geometry, description varchar2(32))");
